@@ -36,6 +36,9 @@ _lib <<
 "    cmp ebx, 's'\n"
 "    je .imp_literal\n"
 "    \n"
+"    cmp ebx, 'l'\n"
+"    je .imp_logico\n"
+"    \n"
 "    jmp .footer\n"
 "\n"
 "      .imp_inteiro:\n"
@@ -81,13 +84,18 @@ _lib <<
 "    begin 0\n"
 "\n"
 "    mov eax, [string]\n"
-"    cmp eax, 0\n"
-"    jz .end\n"
+"    cmp eax, ''\n"
+"    jz .imprima_nulo\n"
 "\n"
 "    addarg dword [string]\n"
 "    call print\n"
 "    clargs 1\n"
+"    jmp .end\n"
 "\n"
+"    .imprima_nulo"
+"      addarg dword str_null\n"
+"      call print\n"
+"      clargs 1\n"
 "\n"
 "    .end:\n"
 "      return\n"
@@ -388,6 +396,8 @@ _lib <<
 "    %undef len\n"
 "    %undef negt\n"
 "\n"
+
+
 "atof:\n"
 "    %define string ebp+8\n"
 "    \n"
@@ -399,12 +409,14 @@ _lib <<
 "    %define integral ebp-24\n"
 "    %define decimal  ebp-28\n"
 "    %define float    ebp-32\n"
+"    %define sign     ebp-36\n"
 "\n"
-"    begin 32\n"
+"    begin 36\n"
 "\n"
 "    mov dword [dot], -1\n"
 "    mov dword [float], 0\n"
-"    \n"
+"    mov dword [sign], 0\n"
+"        \n"
 "    addarg dword [string]\n"
 "    call strlen\n"
 "    clargs 1\n"
@@ -438,8 +450,8 @@ _lib <<
 "      cmp bl, '+'\n"
 "      je .footer\n"
 "      cmp bl, '-'\n"
-"      je .footer\n"
-" \n"
+"      je .neg_footer\n"
+"\n"
 "      addarg ebx\n"
 "      call is_num\n"
 "      clargs 1\n"
@@ -453,7 +465,10 @@ _lib <<
 "      .dot_found:\n"
 "        mov eax, dword [i]\n"
 "        mov dword [dot], eax\n"
-"\n"
+"        jmp .footer\n"
+"        \n"
+"      .neg_footer:\n"
+"        mov dword [sign], 1        \n"
 "      .footer:\n"
 "        inc dword [i]\n"
 "        jmp .while\n"
@@ -493,8 +508,8 @@ _lib <<
 "    fstp dword [decimal]\n"
 "    fld dword [float]\n"
 "\n"
-"    cmp dword [integral], 0\n"
-"    jg .pos\n"
+"    cmp dword [sign], 0 \n"
+"    je .pos\n"
 "      fsub dword [decimal]\n"
 "      jmp .endif2\n"
 "    .pos:\n"
@@ -515,7 +530,10 @@ _lib <<
 "    %undef integral\n"
 "    %undef decimal\n"
 "    %undef float\n"
+"    %undef sign\n"
 "\n"
+
+
 "itoa:    \n"
 "    %define buffer ebp+12\n"
 "    %define num ebp+8\n"
